@@ -9,12 +9,9 @@ def human_readable_size(size_bytes: float) -> str:
 def lazy_import(dotted_path: str):
     import importlib
 
-    import click
-
     try:
         module_path, obj_name = dotted_path.rsplit(".", 1)
         module = importlib.import_module(module_path)
         return getattr(module, obj_name)
     except (ModuleNotFoundError, AttributeError) as e:
-        click.secho(f"failed to load: {dotted_path}\n{e}", fg="red", err=True)
-        raise
+        raise ImportError(f"failed to import: {dotted_path}\n{e}")
